@@ -40,7 +40,7 @@ while (<DICT>) {
 
   ($dummystr, $namestr, $valstr, $typestr, $vendorstr) = split(/\s+/);
  
-  if ($dummystr eq 'ATTRIBUTE') {
+  if ($dummystr =~ 'ATTRIB') {
      $sql = "INSERT INTO dictionary VALUES \(\"\",\"$dummystr\",\"$namestr\",\"$valstr\",\"$typestr\",\"$vendorstr\"\)";
   } elsif ($dummystr eq 'VALUE') {
      $sql = "INSERT INTO dictionary VALUES \(\"\",\"$dummystr\",\"$namestr\",\"$valstr\",\"$typestr\",\"\"\)";
