@@ -211,6 +211,22 @@ static int unix_pass(char *name, char *passwd)
 	if (strcmp(encpw, encrypted_pass))
 		return -1;
 
+#ifdef ETC_SHELL
+        {
+          char *shell;
+
+          while ((shell = getusershell()) != NULL) {
+            if (strcmp(shell, pwd->pw_shell) == 0) {
+              endusershell();
+              return 0;
+            }
+          }
+
+          endusershell();
+          return -1;
+        }
+#endif /* ETC_SHELL */
+
 	return 0;
 }
 
@@ -541,7 +557,6 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 	VALUE_PAIR	*auth_item;
 	VALUE_PAIR	*user_check;
 	VALUE_PAIR	*user_reply;
-	VALUE_PAIR	*proxy_pairs;
 	int		result, r;
 	char		pw_digest[16];
 	char		userpass[128];
@@ -574,12 +589,6 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 	 */
 	calc_digest(pw_digest, authreq);
 
-	/*
-	 *	Move the proxy_state A/V pairs somewhere else.
-	 */
-	proxy_pairs = NULL;
-	pairmove2(&proxy_pairs, &(authreq->request), PW_PROXY_STATE);
-
 	/*
 	 *	If this request got proxied to another server, we need
 	 *	to add an initial Auth-Type: Auth-Accept for success,
@@ -790,8 +799,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			log(L_AUTH, "Invalid user: [%s] (%s)",
 				namepair->strvalue, auth_name(authreq, 1));
 			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq,
-				proxy_pairs, NULL, activefd);
-			pairfree(proxy_pairs);
+				NULL, NULL, activefd);
 			pairfree(user_check);
 			pairfree(user_reply);
 			authfree(authreq);
@@ -822,13 +830,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 #endif
 
 			if (result > 0) {
-				/*
-				 *	FIXME: proxy_pairs is lost in reply.
-				 *	Happens only in the CHAP case, which
-				 *	doesn't work anyway, so ..
-				 */
 				authfree(authreq);
-				pairfree(proxy_pairs);
 				pairfree(user_check);
 				pairfree(user_reply);
 				return -1;
@@ -844,8 +846,6 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 	}
 #endif
 
-	pairmove2(&user_reply, &proxy_pairs, PW_PROXY_STATE);
-
 	if (result < 0) {
 		/*
 		 *	Failed to validate the user.
