@@ -48,8 +48,8 @@ $rusers		= "/usr/bin/rusers";
 #		ports are skipped (22 or 29, for US or Europe)
 #		$lv_hole is the size of the hole (1 or 2, for US or Europe).
 #
-$lv_offs = 22;
-$lv_hole = 1;
+$lv_offs = 29;
+$lv_hole = 2;
 
 #
 #	Try to load Net::Telnet, SNMP_Session etc.
@@ -243,7 +243,7 @@ sub livingston_snmp {
 	#	is greater than 29, substract 2 (S30 and S31 don't exist).
 	#	You might need to change this to 23 and 1 for the USA.
 	#
-	$_ = snmpget($ARGV[1], "public", "$lvm.3.2.1.1.1.2.5");
+	$_ = snmpget($ARGV[1], $ARGV[5], "$lvm.3.2.1.1.1.2.5");
 	/S([0-9]+)/;
 	$xport = $1 + 0;
 	$portidx = $ARGV[2] + (5 - $xport);
@@ -255,7 +255,7 @@ sub livingston_snmp {
 	#
 	#	Now get the session id from the terminal server.
 	#
-	$sessid = snmpget($ARGV[1], "public", "$lvm.3.2.1.1.1.5.$portidx");
+	$sessid = snmpget($ARGV[1], $ARGV[5], "$lvm.3.2.1.1.1.5.$portidx");
 
 	print LOG "  session id at port S$ARGV[2]: $sessid\n" if ($debug);
 
@@ -267,7 +267,7 @@ sub livingston_snmp {
 #
 $csm	 = '.iso.org.dod.internet.private.enterprises.9';
 sub cisco_snmp {
-	$login = snmpget($ARGV[1], "public", "$csm.2.9.2.1.18.$ARGV[2]");
+	$login = snmpget($ARGV[1], $ARGV[5], "$csm.2.9.2.1.18.$ARGV[2]");
 
 	print LOG "  user at port S$ARGV[2]: $login\n" if ($debug);
 
@@ -283,7 +283,7 @@ $msm    = '.iso.org.dod.internet.private.enterprises.995';
 sub multitech_snmp {
 	my $temp = $ARGV[2] + 1;
 
-        $login = snmpget($ARGV[1], "public", "$msm.2.31.1.1.1.$temp");
+        $login = snmpget($ARGV[1], $ARGV[5], "$msm.2.31.1.1.1.$temp");
         print LOG " user at port S$ARGV[2]: $login\n" if ($debug);
 
         ($login eq $ARGV[3]) ? 1 : 0;
@@ -673,7 +673,7 @@ sub usrhiper_snmp {
 	my($oidext) = $ARGV[2] + 1256;
 	my ($login);
 
-	$login = snmpget($ARGV[1], "public", "$usrm.4.10.1.1.18.$oidext");
+	$login = snmpget($ARGV[1], $ARGV[5], "$usrm.4.10.1.1.18.$oidext");
 	($login) = /^.*\"([^"]+)".*$/;
 
 	print LOG "  user at port S$ARGV[2]: $login\n" if ($debug);
@@ -778,9 +778,9 @@ sub versanet_snmp {
 	print LOG "port = $port " if ($debug);
 	$slot = (($ARGV[2]-$port)/8)+1;
 	print LOG "slot = $slot" if ($debug);
-	$loginname = snmpget($ARGV[1], "public", "$vsm.27.1.1.3.$slot.$port");
+	$loginname = snmpget($ARGV[1], $ARGV[5], "$vsm.27.1.1.3.$slot.$port");
 #
-#	Note: the "public" string above could be replaced by the public
+#	Note: the $ARGV[5] above could be replaced by the public
 #	      community string defined in Versanet VN2001/VN2002.
 #
 	  print LOG "  user at slot $slot port $port: $loginname\n" if ($debug);	  ($loginname eq $ARGV[3]) ? 1 : 0;	
@@ -793,11 +793,11 @@ if ($debug) {
 	print LOG "$now checkrad @ARGV\n";
 }
 
-if ($#ARGV != 4) {
+if ($#ARGV != 5) {
 	print LOG "Usage: checkrad nas_type nas_ip " .
-			"nas_port login session_id\n" if ($debug);
+			"nas_port login session_id community\n" if ($debug);
 	print STDERR "Usage: checkrad nas_type nas_ip " .
-			"nas_port login session_id\n";
+			"nas_port login session_id community\n";
 	close LOG if ($debug);
 	exit(2);
 }
