@@ -503,9 +503,9 @@ static int paircmp(VALUE_PAIR *request, VALUE_PAIR *check)
 				}
 				else
 				if (check_item->attribute == PW_HUNTGROUP_NAME){
-					if (!huntgroup_match(request,
-						check_item->strvalue))
-							return -1;
+                                        compare = (huntgroup_match(request,
+                                                check_item->strvalue) == 0);
+                                        DEBUG("COMPARE = %d", compare);                                               break;
 				}
 				else
 				compare = strcmp(auth_item->strvalue,
@@ -2130,6 +2130,27 @@ int read_config_files()
 
 	if (!use_dbm && (users = file_read(buffer, 1)) == NULL)
 		return -1;
+
+        /*
+         *  Double check the 'users' file for sanity
+         */
+        if (!use_dbm) {
+          PAIR_LIST *entry;
+          VALUE_PAIR *pair;
+
+          for (entry = users; entry; entry = entry->next) {
+            for (pair = entry->reply; pair; pair = pair->next) {                            if ((pair->attribute == PW_PASSWORD) ||
+                  (pair->attribute == PW_CHAP_PASSWORD) ||
+                  (pair->attribute >= 1000)) {
+                log(L_ERR|L_CONS, "\n[%s:%d] WARNING: Check item \"%s\"\n"
+                    "\tfound in reply item list for user \"%s\".\n"
+                    "\tThis attribute MUST go on the first line"
+                    " with the other check items.\n", buffer, entry->lineno,
+                    pair->name, entry->name);
+              }
+            }
+          }
+        }
 #endif
 	sprintf(buffer, "%s/%s", radius_dir, RADIUS_HUNTGROUPS);
 	huntgroups = file_read(buffer, 0);
