@@ -1,5 +1,5 @@
 /*
- * mysql.c	MySQL routines. Used bt ICRADIUS 0.7 extensions
+ * mysql.c	MySQL routines. Used bt ICRADIUS 0.9 extensions
  *
  */
 #ifdef USEMYSQL
@@ -296,7 +296,7 @@ int mysql_save_acct(MYSQLREC *sqlrecord) {
          /* The Terminal server informed us that it was rebooted
          * STOP all records from this NAS */
 
-         sprintf(querystr, "UPDATE %s SET AcctStopTime='%s', AcctSessionTime=unix_timestamp('%s') - unix_timestamp(AcctStartTime), AcctTerminateCause='%s' WHERE AcctSessionTime=0 AND AcctStopTime=0 AND NASIPAddress= '%s' AND AcctStartTime <= '%s'", mysql_acct_table, sqlrecord->AcctTimeStamp, sqlrecord->AcctTimeStamp, sqlrecord->AcctTerminateCause, sqlrecord->NASIPAddress, sqlrecord->AcctTimeStamp);
+         sprintf(querystr, "UPDATE %s SET AcctStopTime='%s', AcctSessionTime=unix_timestamp('%s') - unix_timestamp(AcctStartTime), AcctTerminateCause='%s', AcctStopDelay = %ld WHERE AcctSessionTime=0 AND AcctStopTime=0 AND NASIPAddress= '%s' AND AcctStartTime <= '%s'", mysql_acct_table, sqlrecord->AcctTimeStamp, sqlrecord->AcctTimeStamp, sqlrecord->AcctTerminateCause, sqlrecord->AcctDelayTime, sqlrecord->NASIPAddress, sqlrecord->AcctTimeStamp);
 
  	 if (sqltrace)
 	      DEBUG(querystr);
@@ -331,9 +331,10 @@ int mysql_save_acct(MYSQLREC *sqlrecord) {
           if(sqlrecord->AcctStatusTypeId == PW_STATUS_START) {
              
              /* Set start time on record with only a stop record */
- 	     snprintf(querystr, 2048, "UPDATE %s SET AcctStartTime = '%s' WHERE AcctSessionId = '%s' AND UserName = '%s' AND NASIPAddress = '%s'", 
+ 	     snprintf(querystr, 2048, "UPDATE %s SET AcctStartTime = '%s', AcctStartDelay = %ld WHERE AcctSessionId = '%s' AND UserName = '%s' AND NASIPAddress = '%s'", 
 	     mysql_acct_table,
              sqlrecord->AcctTimeStamp,
+	     sqlrecord->AcctDelayTime,
              sqlrecord->AcctSessionId,
              sqlrecord->UserName,
              sqlrecord->NASIPAddress
@@ -347,7 +348,7 @@ int mysql_save_acct(MYSQLREC *sqlrecord) {
              if (num == 0) {
 
                 /* Insert new record with blank stop time until stop record is got */
-                snprintf(querystr, 2048, "INSERT INTO %s VALUES (0, '%s', '%s', '%s', '%s', %ld, '%s', '%s', 0, 0, '%s', '%s', 0, 0, '%s', '%s', '', '%s', '%s', '%s', %ld)",
+                snprintf(querystr, 2048, "INSERT INTO %s VALUES (0, '%s', '%s', '%s', '%s', %ld, '%s', '%s', 0, 0, '%s', '%s', 0, 0, '%s', '%s', '', '%s', '%s', '%s', %ld, 0)",
                 mysql_acct_table,
                 sqlrecord->AcctSessionId,
                 sqlrecord->UserName,
@@ -392,13 +393,14 @@ int mysql_save_acct(MYSQLREC *sqlrecord) {
              if (num > 0) {
 
                 /* Set stop time on matching record with start time */
- 	        snprintf(querystr, 2048, "UPDATE %s SET AcctStopTime = '%s', AcctSessionTime = '%lu', AcctInputOctets = '%u', AcctOutputOctets = '%u', AcctTerminateCause = '%s' WHERE AcctSessionId = '%s' AND UserName = '%s' AND NASIPAddress = '%s'", 
+ 	        snprintf(querystr, 2048, "UPDATE %s SET AcctStopTime = '%s', AcctSessionTime = '%lu', AcctInputOctets = '%lu', AcctOutputOctets = '%lu', AcctTerminateCause = '%s', AcctStopDelay = %ld WHERE AcctSessionId = '%s' AND UserName = '%s' AND NASIPAddress = '%s'", 
 	        mysql_acct_table,
                 sqlrecord->AcctTimeStamp,
                 sqlrecord->AcctSessionTime,
                 sqlrecord->AcctInputOctets,
                 sqlrecord->AcctOutputOctets,
                 sqlrecord->AcctTerminateCause,
+		sqlrecord->AcctDelayTime,
                 sqlrecord->AcctSessionId,
                 sqlrecord->UserName,
                 sqlrecord->NASIPAddress
@@ -414,7 +416,7 @@ int mysql_save_acct(MYSQLREC *sqlrecord) {
 
             
                 /* Insert record with no start time until matching start record comes */
-                snprintf(querystr, 2048, "INSERT INTO %s VALUES (0, '%s', '%s', '%s', '%s', %ld, '%s', 0, '%s', '%lu', '%s', '%s', '%u', '%u', '%s', '%s', '%s', '%s', '%s', '%s', %ld)",
+                snprintf(querystr, 2048, "INSERT INTO %s VALUES (0, '%s', '%s', '%s', '%s', %ld, '%s', 0, '%s', '%lu', '%s', '%s', '%lu', '%lu', '%s', '%s', '%s', '%s', '%s', '%s', 0, %ld)",
                 mysql_acct_table,
                 sqlrecord->AcctSessionId,
                 sqlrecord->UserName,
@@ -672,16 +674,26 @@ int mysql_checksocket(const char *facility) {
 int mysql_getvpdata(char *table, VALUE_PAIR **vp, char *user, int mode) {
 
 	char		querystr[256];
+	char		username[AUTH_STRING_LEN*2+1];
 	MYSQL_RES	*result;
 	MYSQL_ROW	row;
 	int		rows;
+	int		length;
+
+	if (strlen(user) > AUTH_STRING_LEN)
+		length = AUTH_STRING_LEN;
+	else
+		length = strlen(user);
+
+	/* FIXME CHECK user for weird charactors!! */
+	mysql_escape_string(username, user, length);
 
 	if (mode == PW_VP_USERDATA)
-		sprintf(querystr, "SELECT * FROM %s WHERE UserName = '%s'", table, user);
+		sprintf(querystr, "SELECT * FROM %s WHERE UserName = '%s'", table, username);
 	else if (mode == PW_VP_GROUPDATA)
-		sprintf(querystr, "SELECT %s.* FROM %s, %s WHERE %s.UserName = '%s' AND %s.GroupName = %s.GroupName ORDER BY %s.id", table, table, mysql_usergroup_table, mysql_usergroup_table, user, mysql_usergroup_table, table, table);
+		sprintf(querystr, "SELECT %s.* FROM %s, %s WHERE %s.UserName = '%s' AND %s.GroupName = %s.GroupName ORDER BY %s.id", table, table, mysql_usergroup_table, mysql_usergroup_table, username, mysql_usergroup_table, table, table);
 	else if (mode == PW_VP_REALMDATA)
-		sprintf(querystr, "SELECT %s.* FROM %s, %s WHERE %s.RealmName = '%s' AND %s.GroupName = %s.GroupName ORDER BY %s.id", table, table, mysql_realmgroup_table, mysql_realmgroup_table, user, mysql_realmgroup_table, table, table);
+		sprintf(querystr, "SELECT %s.* FROM %s, %s WHERE %s.RealmName = '%s' AND %s.GroupName = %s.GroupName ORDER BY %s.id", table, table, mysql_realmgroup_table, mysql_realmgroup_table, username, mysql_realmgroup_table, table, table);
 	if (sqltrace)
 		DEBUG(querystr);
         mysql_checksocket("Auth");
@@ -739,6 +751,9 @@ static int mysql_check_ts(MYSQL_ROW row) {
                 return -1;
         }
 
+	if (!nas->usesnmp)
+		return 1;
+
         /*
          *      Fork.
          */
@@ -786,11 +801,11 @@ static int mysql_check_ts(MYSQL_ROW row) {
 
         s = CHECKRAD2;
         execl(CHECKRAD2, "checkrad", nas->nastype, row[4], row[5],
-                row[2], session_id, NULL);
+                row[2], session_id, nas->community, NULL);
         if (errno == ENOENT) {
                 s = CHECKRAD1;
                 execl(CHECKRAD1, "checklogin", nas->nastype, row[4], row[5],
-                        row[2], session_id, NULL);
+                        row[2], session_id, nas->community, NULL);
         }
         log(L_ERR, "Check-TS: exec %s: %s", s, strerror(errno));
 
@@ -857,17 +872,21 @@ int mysql_check_multi(char *name, VALUE_PAIR *request, int maxsimul) {
   		MyAuthSock = NULL;
 	} else {
 		while ((row = mysql_fetch_row(result))) {
-			if (mysql_check_ts(row) == 1) {
+			int check = mysql_check_ts(row);
+			if (check == 1) {
 				count++;
 
 				if (ipno && atoi(row[19]) == ipno)
 					mpp = 2;   
 
-			} else {
+			} else if (check == 2)
+				log(L_ERR,"Problem with checkrad [%s] (from nas %s)", name, row[4]);
+			else {
 				/*
 				 *	False record - zap it
 				 */
 
+   				log(L_ERR,"Deleteing stale session [%s] (from nas %s/%s)", row[2], row[4], row[5]);
 				sprintf(querystr, "DELETE FROM %s WHERE RadAcctId = '%s'", mysql_acct_table, row[0]);
 				if (sqltrace)
 					DEBUG(querystr);
@@ -918,7 +937,12 @@ int mysql_read_naslist(char *nastable)
                 	strcpy(c->nastype, row[4]);
                 	strcpy(c->shortname, row[2]);
                 	strcpy(c->longname, row[1]);
-	
+			strncpy(c->community, row[7], MAX_COMMUNITY_LEN);
+			if (strcmp(row[8], "on") == 0 || strcmp(row[8], "ON") == 0)
+				c->usesnmp = 1;
+			else 
+				c->usesnmp = 0; 
+
         	        c->next = naslist;
                 	naslist = c;
         	}
