@@ -572,7 +572,7 @@ int proxy_receive(AUTH_REQ *authreq, int activefd)
 	x       = NULL;
 	prev    = NULL;
 
-	for (vp = authreq->request; vp; vp = vp->next) {
+	for (vp = authreq->proxy_pairs; vp; vp = vp->next) {
 		if (vp->attribute == PW_PROXY_STATE) {
 			prev = x;
 			last = vp;
@@ -613,7 +613,7 @@ int proxy_receive(AUTH_REQ *authreq, int activefd)
 	}
 
 	if (oldreq == NULL) {
-		log(L_PROXY, "Unreckognized proxy reply from server %s - ID %d",
+		log(L_PROXY, "Unrecognized proxy reply from server %s - ID %d",
 			client_name(authreq->ipaddr), authreq->id);
 		return -1;
 	}
@@ -633,7 +633,7 @@ int proxy_receive(AUTH_REQ *authreq, int activefd)
 		if (prev)
 			prev->next = last->next;
 		else
-			authreq->request = last->next;
+			authreq->proxy_pairs = last->next;
 	}
 
 #if 0 /* Not needed anymore. */
