@@ -82,6 +82,7 @@ typedef struct auth_req {
 	UINT4			timestamp;
 	u_char			*data;		/* Raw received data */
 	int			data_len;
+	VALUE_PAIR		*proxy_pairs;
 	/* Proxy support fields */
 	u_char			realm[32];
 	int			validated;	/* Already md5 checked */
@@ -105,6 +106,8 @@ typedef struct nas {
 	char			longname[256];
 	char			shortname[32];
 	char			nastype[32];
+	char			community[MAX_COMMUNITY_LEN];
+	int			usesnmp;
 	struct nas		*next;
 } NAS;
 
